@@ -1,9 +1,9 @@
 import os
-from textile import textile
 import logging
 from lamson import view, queue
 import email
 from config.settings import BLOG_BASE
+from markdown import markdown
 
 
 def delete(post_name, user):
@@ -13,22 +13,21 @@ def delete(post_name, user):
         logging.debug("DELETING %s", file_name)
         os.unlink(file_name)
         remove_from_queue(post_name, user)
-    else:
-        logging.warning("FILE DOES NOT EXIST: %r", file_name)
 
 
-def post(post_name, user, message):
+def post(post_name, user, host, message):
     user_dir = make_user_dir(user)
+    user_id, domain = user.split("@")
 
     # make sure it's removed first if it existed
     delete(post_name, user)
 
     posting = open("%s/%s.html" % (user_dir, post_name), "w")
-    content = textilize(message.body())
+    content = markdown(message.body())
 
-    html = view.render("post.html", locals())
+    html = view.render("web/post.html", locals())
 
-    posting.write(html)
+    posting.write(html.encode('utf-8'))
 
     post_q = get_user_post_queue(user_dir)
     post_q.push(message)
@@ -66,8 +65,3 @@ def get_user_post_queue(user_dir):
     queue_dir = "%s/posts_queue" % (user_dir)
     return queue.Queue(queue_dir)
 
-def textilize(text):
-    return textile(text.encode('utf-8'),
-                   head_offset=0, validate=0, 
-                   sanitize=0, encoding='utf-8', 
-                   output='utf-8')
