@@ -4,10 +4,11 @@ from lamson.server import Relay, QueueReceiver
 from lamson.utils import configure_database
 from lamson import view
 import logging
+import logging.config
 import jinja2
 
 # configure logging to go to a log file
-logging.basicConfig(filename=settings.log_file, level=logging.DEBUG)
+logging.config.fileConfig("config/logging.conf")
 
 # the relay host to actually send the final message to
 settings.relay = Relay(host=settings.relay_config['host'], 
