@@ -3,9 +3,6 @@ from app.model import table
 from lamson import queue, routing
 import logging
 
-# configure logging to go to a log file
-log_file = "logs/lamson.log"
-
 relay_config = {'host': 'localhost', 'port': 8825}
 
 receiver_config = {'host': 'localhost', 'port': 8823}
