@@ -25,31 +25,28 @@ with *args.
 See lamson.args for more details.
 """
 
-from lamson import server, args, utils, queue, mail, routing
+from lamson import server, args, utils, mail, routing, queue, encoding
 from pkg_resources import resource_stream
 from zipfile import ZipFile
 import glob
-import imp
 import lamson
-import logging
 import os
 import signal
-import smtplib
 import sys
 import time
+import mailbox
 
-
-def log_command(port=8825, host='127.0.0.1', debug=1, queue="", chroot=False,
-                cd=".", uid=False, gid=False, umask=False, pid="./run/log.pid",
+def log_command(port=8825, host='127.0.0.1', chroot=False,
+                chdir=".", uid=False, gid=False, umask=False, pid="./run/log.pid",
                FORCE=False):
     """
     Runs a logging only server on the given hosts and port.  It logs
     each message it receives and also stores it to the run/queue 
     so that you can make sure it was received in testing.
 
-    lamson log -port 8825 -host 127.0.0.1 -debug 1 \\
+    lamson log -port 8825 -host 127.0.0.1 \\
             -pid ./run/log.pid -chroot False  \\
-            -cd "." -umask False -uid False -gid False \\
+            -chdir "." -umask False -uid False -gid False \\
             -FORCE False
 
     If you specify a uid/gid then this means you want to first change to
@@ -61,31 +58,30 @@ def log_command(port=8825, host='127.0.0.1', debug=1, queue="", chroot=False,
     uid or gid without doing the priv drop operation.
     """
     loader = lambda: utils.make_fake_settings(host, port)
-    utils.start_server(pid, FORCE, chroot, cd, uid, gid, umask, loader)
+    utils.start_server(pid, FORCE, chroot, chdir, uid, gid, umask, loader)
 
 
 def send_command(port=8825, host='127.0.0.1', debug=1, sender=None, to=None,
-                 subject=None, body=None, file=False):
+                 subject=None, body=None, attach=False):
     """
     Sends an email to someone as a test message.
     See the sendmail command for a sendmail replacement.
     
     lamson send -port 8825 -host 127.0.0.1 -debug 1 \\
-            -sender EMAIL -to EMAIL -subject STR -body STR -file False'
+            -sender EMAIL -to EMAIL -subject STR -body STR -attach False'
     """
     message = mail.MailResponse(From=sender,
                                   To=to,
                                   Subject=subject,
                                   Body=body)
-    if file:
-        message.attach(file)
+    if attach:
+        message.attach(attach)
 
-    relay = server.Relay(host, port=port,
-                         debug=debug)
+    relay = server.Relay(host, port=port, debug=debug)
     relay.deliver(message)
 
 
-def sendmail_command(port=8825, host='127.0.0.1', debug=0, TRAILING=[]):
+def sendmail_command(port=8825, host='127.0.0.1', debug=0, TRAILING=None):
     """
     Used as a testing sendmail replacement for use in programs
     like mutt as an MTA.  It reads the email to send on the stdin
@@ -109,19 +105,20 @@ def syncdb_command(create=True):
     """
     settings = utils.import_settings(False, from_dir=os.getcwd())
     database = utils.configure_database(settings.database_config)
-    database.create()
+    if create:
+        database.create()
 
 
-def start_command(pid='./run/smtp.pid', FORCE=False, chroot=False, cd=".",
+def start_command(pid='./run/smtp.pid', FORCE=False, chroot=False, chdir=".",
                   boot="config.boot", uid=False, gid=False, umask=False):
     """
     Runs a lamson server out of the current directory:
 
-    lamson start -pid ./run/smtp.pid -FORCE False -chroot False -cd "." \\
+    lamson start -pid ./run/smtp.pid -FORCE False -chroot False -chdir "." \\
             -umask False -uid False -gid False -boot config.boot
     """
     loader = lambda: utils.import_settings(True, from_dir=os.getcwd(), boot_module=boot)
-    utils.start_server(pid, FORCE, chroot, cd, uid, gid, umask, loader)
+    utils.start_server(pid, FORCE, chroot, chdir, uid, gid, umask, loader)
 
 
 def stop_command(pid='./run/smtp.pid', KILL=False, ALL=False):
@@ -147,9 +144,8 @@ def stop_command(pid='./run/smtp.pid', KILL=False, ALL=False):
 
     print "Stopping processes with the following PID files: %s" % pid_files
 
-    # TODO: carve this out into a separate function
-    for file in pid_files:
-        pid = open(file).readline()
+    for pid_f in pid_files:
+        pid = open(pid_f).readline()
 
         print "Attempting to stop lamson at pid %d" % int(pid)
 
@@ -159,7 +155,7 @@ def stop_command(pid='./run/smtp.pid', KILL=False, ALL=False):
             else:
                 os.kill(int(pid), signal.SIGHUP)
             
-            os.unlink(file)
+            os.unlink(pid_f)
         except OSError, exc:
             print "ERROR stopping Lamson on PID %d: %s" % (int(pid), exc)
 
@@ -200,9 +196,9 @@ def help_command(**options):
     lamson help -for STR
     """
     if "for" in options:
-        help = args.help_for_command(lamson.commands, options['for'])
-        if help:
-            print help
+        help_text = args.help_for_command(lamson.commands, options['for'])
+        if help_text:
+            print help_text
         else:
             args.invalid_command_message(lamson.commands, exit_on_error=True)
     else:
@@ -219,23 +215,23 @@ def queue_command(pop=False, get=False, keys=False, remove=False, count=False,
     """
     print "Using queue: %r" % name
 
-    q = queue.Queue(name)
+    inq = queue.Queue(name)
 
     if pop:
-        key, msg = q.pop()
+        key, msg = inq.pop()
         if key:
             print "KEY: ", key
             print msg
     elif get:
-        print q.get(get)
+        print inq.get(get)
     elif remove:
-        q.remove(remove)
+        inq.remove(remove)
     elif count:
-        print "Queue %s contains %d messages" % (name, q.count())
+        print "Queue %s contains %d messages" % (name, inq.count())
     elif clear:
-        q.clear()
+        inq.clear()
     elif keys:
-        print "\n".join(q.keys())
+        print "\n".join(inq.keys())
     else:
         print "Give something to do.  Try lamson help -for queue to find out what."
         sys.exit(1)
@@ -308,18 +304,20 @@ def gen_command(project=None):
     os.makedirs(project)
     files = prototype.namelist()
 
-    for file in files:
-        if str(file).endswith('/'):
-            target = os.path.join(project, file)
+    for gen_f in files:
+        if str(gen_f).endswith('/'):
+            target = os.path.join(project, gen_f)
             if not os.path.exists(target):
                 print "mkdir: %s" % target
                 os.makedirs(target)
         else:
-            target = os.path.join(project, file)
-            if os.path.exists(target): continue
+            target = os.path.join(project, gen_f)
+            if os.path.exists(target): 
+                continue
+
             print "copy: %s" % target
             out = open(target, 'w')
-            out.write(prototype.read(file))
+            out.write(prototype.read(gen_f))
             out.close()
 
 def spell_command(TRAILING=None, language="en_US"):
@@ -335,7 +333,7 @@ def spell_command(TRAILING=None, language="en_US"):
     sys.path.append(os.getcwd())
 
     try:
-        from config import testing
+        __import__("config.testing", globals(), locals())
     except ImportError, exc:
         print "Couldn't import config.testing, assuming you know what you're doing."
 
@@ -361,18 +359,18 @@ def spell_command(TRAILING=None, language="en_US"):
         print exc
         return False
 
-    for file in TRAILING:
-        text = open(file).read()
-        chkr = SpellChecker(language,filters=[EmailFilter,URLFilter]) 
+    for check_f in TRAILING:
+        text = open(check_f).read()
+        chkr = SpellChecker(language, filters=[EmailFilter, URLFilter]) 
         chkr.set_text(text) 
         cmdln = CmdLineChecker() 
         cmdln.set_checker(chkr) 
         cmdln.run()
         new_text = chkr.get_text()
         if new_text != text:
-            print "Saving old text to %s.bak and writing changes." % file
-            open(file + ".bak", "w").write(text)
-            open(file, "w").write(new_text)
+            print "Saving old text to %s.bak and writing changes." % check_f
+            open(check_f + ".bak", "w").write(text)
+            open(check_f, "w").write(new_text)
 
     return True
 
@@ -389,11 +387,39 @@ def web_command(basedir=".", port=8888, host='127.0.0.1'):
     """
     from BaseHTTPServer import HTTPServer
     from SimpleHTTPServer import SimpleHTTPRequestHandler 
-    import os
 
     os.chdir(basedir)
-    server = HTTPServer((host, port), SimpleHTTPRequestHandler)
+    web = HTTPServer((host, port), SimpleHTTPRequestHandler)
     print "Starting server on %s:%d out of directory %r" % (
         host, port, basedir)
-    server.serve_forever()
+    web.serve_forever()
+
+
+def cleanse_command(input=None, output=None):
+    """
+    Uses Lamson mail cleansing and canonicalization system to take an
+    input maildir (or mbox) and replicate the email over into another
+    maildir.  It's used mostly for testing and cleaning.
+    """
+    error_count = 0
+
+    try:
+        inbox = mailbox.mbox(input)
+    except:
+        inbox = mailbox.Maildir(input)
+
+    outbox = mailbox.Maildir(output)
+
+    for msg in inbox:
+        try:
+            mail = encoding.from_message(msg)
+            outbox.add(encoding.to_string(mail))
+        except encoding.EncodingError, exc:
+            print "ERROR: ", exc
+            error_count += 1
+
+    outbox.close()
+    inbox.close()
+
+    print "TOTAL ERRORS:", error_count
 
