@@ -183,25 +183,25 @@ class RoutingBase(object):
         self.REGISTERED = {}
         self.ORDER = []
         self.DEFAULT_CAPTURES = {}
-        self.STATE_STORE=MemoryStorage()
-        self.HANDLERS=set()
-        self.RELOAD=False
-        self.UNDELIVERABLE_QUEUE=None
+        self.STATE_STORE = MemoryStorage()
+        self.HANDLERS = set()
+        self.RELOAD = False
+        self.UNDELIVERABLE_QUEUE = None
         self.lock = threading.RLock()
         self.call_lock = threading.RLock()
 
-    def register_route(self, format, fn):
+    def register_route(self, format, func):
         """
-        Registers this function fn into the routes mapping based on the
+        Registers this function func into the routes mapping based on the
         format given.  Format should be a regex string ready to be handed to
         re.compile.
         """
         with self.lock:
             if format in self.REGISTERED:
-                self.REGISTERED[format][1].append(fn)
+                self.REGISTERED[format][1].append(func)
             else:
                 self.ORDER.append(format)
-                self.REGISTERED[format] = (re.compile(format), [fn])
+                self.REGISTERED[format] = (re.compile(format), [func])
 
     def match(self, address):
         """
@@ -231,37 +231,41 @@ class RoutingBase(object):
         """
         with self.lock:
             self.DEFAULT_CAPTURES.update(captures)
+
+    def get_state(self, module_name, message):
+        """Returns the state that this module is in for the given message (using its from)."""
+        _, address = email.utils.parseaddr(message['from'])
+        return self.STATE_STORE.get(module_name, address)
+
     
-    def in_state(self, fn, message):
+    def in_state(self, func, message):
         """
-        Determines if this function's is in the state for the to/from in the
+        Determines if this function is in the state for the to/from in the
         message.  Doesn't apply to @stateless state handlers.
         """
-        name, address = email.utils.parseaddr(message['from'])
-        state = self.STATE_STORE.get(fn.__module__, address)
-        return state and state == fn.__name__
+        state = self.get_state(func.__module__, message)
+        return state and state == func.__name__
 
-    def in_error(self, fn, message):
+    def in_error(self, func, message):
         """
         Determines if the this function is in the 'ERROR' state, 
         which is a special state that self puts handlers in that throw
         an exception.
         """
-        name, address = email.utils.parseaddr(message['from'])
-        state = self.STATE_STORE.get(fn.__module__, address)
+        state = self.get_state(func.__module__, message)
         return state and state == 'ERROR'
 
 
-    def set_state(self, fn, message, state):
+    def set_state(self, module_name, message, state):
         """
-        Sets the state of the given fn according to the message to the requested
-        state.  This is also how you can force another FSM to a required state.
+        Sets the state of the given module (a string) according to the message to the requested
+        state (a string).  This is also how you can force another FSM to a required state.
         """
-        name, address = email.utils.parseaddr(message['from'])
-        self.STATE_STORE.set(fn.__module__, address, state)
+        _, address = email.utils.parseaddr(message['from'])
+        self.STATE_STORE.set(module_name, address, state)
 
 
-    def deliver(self, message, *args, **kw):
+    def deliver(self, message):
         """
         The meat of the whole Lamson operation, this method takes all the
         arguments given, and then goes through the routing listing to figure out
@@ -275,30 +279,34 @@ class RoutingBase(object):
 
         It will log which handlers are being run, and you can use the 'lamson route'
         command to inspect and debug routing problems.
+
+        If you have an ERROR state function, then when your state blows up, it will
+        transition to ERROR state and call your function right away.  It will then
+        stay in the ERROR state unless you return a different one.
         """
         if self.RELOAD: self.reload()
 
         called_count = 0
 
-        for functions, kw in self.match(message['to']):
+        for functions, matchkw in self.match(message['to']):
             to_call = []
             in_state_found = False
 
-            for fn in functions:
-                if lamson_setting(fn, 'stateless'):
-                    to_call.append(fn)
-                elif not in_state_found and self.in_state(fn, message):
-                    to_call.append(fn)
+            for func in functions:
+                if lamson_setting(func, 'stateless'):
+                    to_call.append(func)
+                elif not in_state_found and self.in_state(func, message):
+                    to_call.append(func)
                     in_state_found = True
 
             called_count += len(to_call)
 
-            for fn in to_call:
-                if lamson_setting(fn, 'nolocking'):
-                    self.call_safely(fn, message, args, kw)
+            for func in to_call:
+                if lamson_setting(func, 'nolocking'):
+                    self.call_safely(func, message,  matchkw)
                 else:
                     with self.call_lock:
-                        self.call_safely(fn, message, args, kw)
+                        self.call_safely(func, message, matchkw)
 
         if called_count == 0:
             if self.UNDELIVERABLE_QUEUE:
@@ -310,18 +318,18 @@ class RoutingBase(object):
                           message['to'], message['from'])
 
 
-    def call_safely(self, fn, message, args, kw):
+    def call_safely(self, func, message, kwargs):
         """
         Used by self to call a function and log exceptions rather than
         explode and crash.
         """
         try:
-            fn(message, *args, **kw)
+            func(message, **kwargs)
             LOG.debug("Message to %s was handled by %s.%s",
-                          message['to'], fn.__module__, fn.__name__)
+                          message['to'], func.__module__, func.__name__)
         except:
-            LOG.exception("!!! ERROR handling %s.%s", fn.__module__, fn.__name__)
-            self.set_state(fn, message, 'ERROR')
+            LOG.exception("!!! ERROR handling %s.%s", func.__module__, func.__name__)
+            self.set_state(func.__module__, message, 'ERROR')
 
     def clear_states(self):
         """Clears out the states for unit testing."""
@@ -401,35 +409,33 @@ class route(object):
         with the proper keyword parameters.
 
         You should also use the Router.defaults() to set default things like the
-        host so that you aren't putting it into your code.
+        host so that you are not putting it into your code.
         """
         self.captures = Router.DEFAULT_CAPTURES.copy()
         self.captures.update(captures)
         self.format = self.parse_format(format, self.captures)
 
-    def __call__(self, fn):
+    def __call__(self, func):
         """Returns either a decorator that does a stateless routing or
         a normal routing."""
-        self.setup_accounting(fn)
+        self.setup_accounting(func)
 
-        if lamson_setting(fn, 'stateless'):
-            @wraps(fn)
+        if lamson_setting(func, 'stateless'):
+            @wraps(func)
             def routing_wrapper(message, *args, **kw):
-                next_state = fn(message, *args, **kw)
+                next_state = func(message, *args, **kw)
         else:
-            @wraps(fn)
+            @wraps(func)
             def routing_wrapper(message, *args, **kw):
-                assert Router.in_state(fn, message), "State handler %s called but not in that state." % fn.__name__
-
-                next_state = fn(message, *args, **kw)
+                next_state = func(message, *args, **kw)
 
                 if next_state:
-                    Router.set_state(fn, message, next_state.__name__)
+                    Router.set_state(func.__module__, message, next_state.__name__)
 
         Router.register_route(self.format, routing_wrapper)
         return routing_wrapper
 
-    def __get__(self, obj, type=None):
+    def __get__(self, obj, of_type=None):
         """
         This is NOT SUPPORTED.  It is here just so that if you try to apply
         this decorator to a class's method it will barf on you.
@@ -442,30 +448,30 @@ class route(object):
             format = format.replace("(" + key + ")", "(?P<%s>%s)" % (key, captures[key]))
         return "^" + format + "$"
 
-    def setup_accounting(self, fn):
-        """Sets up an accounting map attached to the fn for routing decorators."""
-        attach_lamson_settings(fn)
-        fn._lamson_settings['format']= self.format
-        fn._lamson_settings['captures'] = self.captures
+    def setup_accounting(self, func):
+        """Sets up an accounting map attached to the func for routing decorators."""
+        attach_lamson_settings(func)
+        func._lamson_settings['format'] = self.format
+        func._lamson_settings['captures'] = self.captures
 
 
-def lamson_setting(fn, key):
+def lamson_setting(func, key):
     """Simple way to get the lamson setting off the function, or None."""
-    return fn._lamson_settings.get(key)
+    return func._lamson_settings.get(key)
 
 
-def has_lamson_settings(fn):
-    return "_lamson_settings" in fn.__dict__
+def has_lamson_settings(func):
+    return "_lamson_settings" in func.__dict__
 
-def assert_lamson_settings(fn):
-    """Used to make sure that the fn has been setup by a routing decorator."""
-    assert has_lamson_settings(fn), "Function %s has not be setup with a @route first." % fn.__name__
+def assert_lamson_settings(func):
+    """Used to make sure that the func has been setup by a routing decorator."""
+    assert has_lamson_settings(func), "Function %s has not be setup with a @route first." % func.__name__
 
 
-def attach_lamson_settings(fn):
+def attach_lamson_settings(func):
     """Use this to setup the _lamson_settings if they aren't already there."""
-    if '_lamson_settings' not in fn.__dict__:
-        fn._lamson_settings = {}
+    if '_lamson_settings' not in func.__dict__:
+        func._lamson_settings = {}
 
 
 class route_like(route):
@@ -474,13 +480,13 @@ class route_like(route):
     handler.  Use this, passing in the other function.  It even works across
     modules.
     """
-    def __init__(self, fn):
-        assert_lamson_settings(fn)
-        self.format = fn._lamson_settings['format']
-        self.captures = fn._lamson_settings['captures']
+    def __init__(self, func):
+        assert_lamson_settings(func)
+        self.format = func._lamson_settings['format']
+        self.captures = func._lamson_settings['captures']
 
 
-def stateless(fn):
+def stateless(func):
     """
     This simple decorator is attached to a handler to indicate to the
     Router.deliver() method that it does NOT maintain state or care about it.
@@ -492,15 +498,15 @@ def stateless(fn):
 
     Stateless handlers are NOT guaranteed to run before the handler with state.
     """
-    if has_lamson_settings(fn):
-        assert not lamson_setting(fn, 'format'), "You must use @stateless AFTER @route or @route_like."
+    if has_lamson_settings(func):
+        assert not lamson_setting(func, 'format'), "You must use @stateless AFTER @route or @route_like."
     
-    attach_lamson_settings(fn)
-    fn._lamson_settings['stateless'] = True
+    attach_lamson_settings(func)
+    func._lamson_settings['stateless'] = True
 
-    return fn
+    return func
 
-def nolocking(fn):
+def nolocking(func):
     """
     Normally lamson.routing.Router has a lock around each call to all handlers
     to prevent them from stepping on eachother.  It's assumed that 95% of the
@@ -513,8 +519,8 @@ def nolocking(fn):
     don't care about threading issues or that you have found a need to 
     manually tune, and it will run it without any locks.
     """
-    attach_lamson_settings(fn)
-    fn._lamson_settings['nolocking'] = True
-    return fn
+    attach_lamson_settings(func)
+    func._lamson_settings['nolocking'] = True
+    return func
 
 
