@@ -11,14 +11,9 @@ periodically use the SpamBayes tools to train from that.
 """
 
 from functools import wraps
-from lamson import server, queue
-from spambayes import hammie, Options, mboxutils, storage
-from spambayes.Version import get_current_version
-import email
-import logging
-import os, os.path
-import sys
-import time
+from lamson import queue
+from spambayes import hammie, Options, storage
+import os
 
 class Filter(object):
     """
@@ -114,22 +109,27 @@ class spam_filter(object):
     def __call__(self, fn):
         @wraps(fn)
         def category_wrapper(message, *args, **kw):
-            if self.spam(message):
-                self.enqueue_as_spam(message)
+            if self.spam(message.to_message()):
+                self.enqueue_as_spam(message.to_message())
                 return self.next_state
             else:
                 return fn(message, *args, **kw)
         return category_wrapper
 
-    def __get__(self, obj, type=None):
+    def __get__(self, obj, of_type=None):
         raise RuntimeError("Not supported on methods yet, only module functions.")
 
     def spam(self, message):
-        filter = Filter(self.storage, self.config)
-        filter.filter(message.msg)
-        return message.msg['X-Spambayes-Classification'].startswith('spam')
+        """Determines if the message is spam or not."""
+        spfilter = Filter(self.storage, self.config)
+        spfilter.filter(message)
+        if 'X-Spambayes-Classification' in message:
+            return message['X-Spambayes-Classification'].startswith('spam')
+        else:
+            return 'ham'
 
     def enqueue_as_spam(self, message):
-        q = queue.Queue(self.spam_queue)
-        q.push(str(message))
+        """Drops the message into the configured spam queue."""
+        outq = queue.Queue(self.spam_queue)
+        outq.push(str(message))
 
