@@ -8,12 +8,8 @@ can be improved feel free to work up a patch.
 from lamson import server, routing
 import sys, os
 import logging
-import grp
-import signal
 import daemon
 from daemon import pidlockfile
-import lockfile
-import logging
 import imp
 
 
@@ -22,7 +18,7 @@ def import_settings(boot_also, from_dir=None, boot_module="config.boot"):
     if from_dir:
         sys.path.append(from_dir)
 
-    from config import settings
+    settings = __import__("config.settings", globals(), locals()).settings
 
     if boot_also:
         __import__(boot_module, globals(), locals())
@@ -30,7 +26,7 @@ def import_settings(boot_also, from_dir=None, boot_module="config.boot"):
     return settings
 
 
-def daemonize(pid, cd, chroot, umask, files_preserve=[], do_open=True):
+def daemonize(pid, chdir, chroot, umask, files_preserve=None, do_open=True):
     """
     Uses python-daemonize to do all the junk needed to make a
     server a server.  It supports all the features daemonize
@@ -38,11 +34,11 @@ def daemonize(pid, cd, chroot, umask, files_preserve=[], do_open=True):
     some serious configuration on the system.
     """
     context = daemon.DaemonContext()
-    context.pidfile=pidlockfile.PIDLockFile(pid)
-    context.stdout=open("logs/lamson.out","a+")
-    context.stderr=open("logs/lamson.err","a+")
-    context.files_preserve = files_preserve
-    context.working_directory=os.path.expanduser(cd)
+    context.pidfile = pidlockfile.PIDLockFile(pid)
+    context.stdout = open("logs/lamson.out","a+")
+    context.stderr = open("logs/lamson.err","a+")
+    context.files_preserve = files_preserve or []
+    context.working_directory = os.path.expanduser(chdir)
     
     if chroot: 
         context.chroot_directory = os.path.expanduser(chroot)
@@ -96,25 +92,30 @@ def make_fake_settings(host, port):
     settings.receiver = server.SMTPReceiver(host, port)
     settings.relay = None
     settings.database = None
-    settings.log_file = "logs/lamson.log"
     logging.info("Logging mode enabled, will not send email to anyone, just log.")
 
     return settings
 
-def check_for_pid(pid, FORCE):
+def check_for_pid(pid, force):
+    """Checks if a pid file is there, and if it is sys.exit.  If force given
+    then it will remove the file and not exit if it's there."""
     if os.path.exists(pid):
-        if not FORCE:
-            print "PID file %s exists, so assuming Lamson is running.  Give -FORCE to force it to start." % pid
+        if not force:
+            print "PID file %s exists, so assuming Lamson is running.  Give -force to force it to start." % pid
             sys.exit(1)
             return # for unit tests mocking sys.exit
         else:
             os.unlink(pid)
 
 
-def start_server(pid, FORCE, chroot, cd, uid, gid, umask, settings_loader):
-    check_for_pid(pid, FORCE)
+def start_server(pid, force, chroot, chdir, uid, gid, umask, settings_loader):
+    """
+    Starts the server by doing a daemonize and then dropping priv
+    accordingly.  It will only drop to the uid/gid given if both are given.
+    """
+    check_for_pid(pid, force)
 
-    daemonize(pid, cd, chroot, umask, files_preserve=[])
+    daemonize(pid, chdir, chroot, umask, files_preserve=[])
 
     sys.path.append(os.getcwd())
 
