@@ -21,23 +21,23 @@ def load(template):
     assert LOADER, "You haven't set lamson.view.LOADER to a loader yet."
     return LOADER.get_template(template)
 
-def render(template, vars):
+def render(template, variables):
     """
-    Takes the vars givens and renders the template for you.
+    Takes the variables given and renders the template for you.
     Assumes the template returned by load() will have a .render()
-    method that takes the vars as a dict.
+    method that takes the variables as a dict.
 
     Use this if you just want to render a single template and don't
     want it to be a message.  Use render_message if the contents
     of the template are to be interpreted as a message with headers
     and a body.
     """
-    return load(template).render(vars)
+    return load(template).render(variables)
 
-def respond(template, vars, html=False):
+def respond(template, variables, html=False):
     """
     Returns a lamson.mail.MailResponse object that is the result
-    of rendering the given template with the vars, parsing the
+    of rendering the given template with the variables, parsing the
     results as an email message, and then setting the body
     as either the Body of the MailResponse or Html of the 
     MailResponse, depending on how html is set.
@@ -46,14 +46,17 @@ def respond(template, vars, html=False):
     email.message_from_string() to work properly in Python 2.6.
     """
 
-    results = render(template, vars)
+    results = render(template, variables)
+
     data = email.message_from_string(results.encode('ascii', 'replace'))
+
     if html:
         msg = mail.MailResponse(Html=data.get_payload())
     else:
         msg = mail.MailResponse(Body=data.get_payload())
 
     msg.update(data)
+
     return msg
 
 
