@@ -1,9 +1,6 @@
 # This file contains python variables that configure Lamson for email processing.
 import logging
 
-# configure logging to go to a log file
-log_file = "logs/lamson.log"
-
 relay_config = {'host': 'localhost', 'port': 8825}
 
 receiver_config = {'host': 'localhost', 'port': 8823}
