@@ -27,7 +27,7 @@ def test_send_command():
                            to='test@test.com',
                            body='Test body',
                            subject='Test subject',
-                           file='setup.py',
+                           attach='setup.py',
                            port=8899,debug=0)
 
 def test_status_command():
