@@ -22,7 +22,7 @@ def test_router():
 def test_receiver():
     receiver = server.SMTPReceiver(host="localhost", port=8824)
     msg = test_mail_request()
-    receiver.process_message(msg.Peer, msg.From, msg.To, msg.Data)
+    receiver.process_message(msg.Peer, msg.From, msg.To, str(msg))
 
 def test_database():
     metadata = MetaData()
