@@ -19,14 +19,14 @@ def teardown():
 
 def test_Filter():
     sf = spam.Filter(ham_db, 'tests/.hammierc')
-    ham_msg = test_mail_request().msg
+    ham_msg = test_mail_request().to_message()
     spam_msg = test_mail_response_plain_text().as_message()
     sf.newdb()
 
     sf.train_ham(ham_msg)
     sf.train_spam(spam_msg)
 
-    sf.untrain_ham(test_mail_request().msg)
+    sf.untrain_ham(test_mail_request().to_message())
     sf.untrain_spam(spam_msg)
 
     sf.close()
@@ -40,14 +40,16 @@ def test_spam_filter():
 
     sf = spam.Filter(ham_db, 'tests/.hammierc')
     msg = test_mail_request()
-    sf.train_spam(msg.msg)
+    sf.train_spam(msg.to_message())
 
     Router.deliver(msg)
+    print Router.STATE_STORE.states
+    print Router.REGISTERED
     assert Router.in_state(spam_filtered_mod.SPAMMING, msg), "Spam got through"
 
     Router.clear_states()
-    sf.untrain_spam(msg.msg)
-    sf.train_ham(msg.msg)
+    sf.untrain_spam(msg.to_message())
+    sf.train_ham(msg.to_message())
 
     Router.deliver(msg)
     print Router.STATE_STORE.states
